==> bayonne-0.5.16.tar.gz: bayonne-0.5.16/drivers/dialogic/record.cpp <==
// Copyright (C) 2000 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// As a special exception to the GNU General Public License, permission is
// granted for additional uses of the text contained in its release
// of Bayonne as noted here.
//
// This exception is that permission is hereby granted to link Bayonne 
// with  the Pika MonteCarlo libraries to produce a executable image
// without requiring MonteCarlo itself to be supplied in source form so
// long as each source file so linked contains this exclusion.
//
// This exception does not however invalidate any other reasons why
// the resulting executable file might be covered by the GNU General
// public license or invalidate the licensing requirements of any
// other component or library.
//
// This exception applies only to the code released by OST under the
// name Bayonne.  If you copy code from other releases into a copy of
// Bayonne, as the General Public License permits, the exception does not
// apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own to Bayonne, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice, at which
// point the terms of your modification would be covered under the GPL
// as explicitly stated in "COPYING".

#include "driver.h"

bool DialogicTrunk::recordHandler(TrunkEvent *event)
{
	struct tm *dt, tbuf;
	struct stat ino;
	char buffer[32];
	char *ext, *fn;
	audioinfo_t info;
	unsigned mask;
	
	switch(event->id)
	{
	case TRUNK_STOP_STATE:
		TimerPort::endTimer();
		handler = &DialogicTrunk::stepHandler;
		endRecord();
		return true;
	case TRUNK_DTMF_KEYUP:
		mask = (1 << event->parm.dtmf.digit);
		if(!(mask & data.record.term))
			return false;
	case TRUNK_AUDIO_IDLE:
		TimerPort::endTimer();
		TrunkSignal(TRUNK_SIGNAL_STEP);
		handler = &DialogicTrunk::stepHandler;
		endRecord();
		return true;
	case TRUNK_ENTER_STATE:
		debug->DebugState(this, "record");
		status[id] = 'r';
		if(!flags.offhook && interface == NT_ANALOG)
		{
			setHook(true);
			flags.offhook = true;
			return true;
		}
	case TRUNK_OFF_HOOK:
		TimerPort::setTimer(data.record.timeout);
		if(data.record.term)
			setDTMFDetect(true);
		else
			Trunk::setDTMFDetect();
		getName(buffer);

		ext = strrchr(data.record.name, '.');
		info.format = AUDIO_FORMAT_RAW;
		info.encoding = MULAW_AUDIO_ENCODING;
		info.order = 0;
		info.annotation = trunk->getSymbol(SYM_ANNOTATION);
		info.rate = 8000;

		if(!ext)
			ext = trunk->getSymbol(SYM_EXTENSION);

		if(!stricmp(ext, ".al"))
			info.encoding = ALAW_AUDIO_ENCODING;
		else if(!stricmp(ext, ".au"))
		{
			info.format = AUDIO_FORMAT_SUN;
			info.order = __BIG_ENDIAN;
		}
		else if(!stricmp(ext, ".wav"))
		{
			info.format = AUDIO_FORMAT_RIFF;
			info.order = __LITTLE_ENDIAN;
		}
		else if(!stricmp(ext, ".vox"))
			info.encoding = DIALOGIC_ADPCM_ENCODING;

		if(data.record.append)
			Open(data.record.name);
		else
			Create(data.record.name, &info);

		fn = getPlayfile();
		if(!isOpen())
		{
			slog(SLOG_ERROR) << data.record.name << ": cannot open" << endl;
			setSymbol(SYM_ERROR, "record-failed");
			TrunkSignal(TRUNK_SIGNAL_ERROR);
			handler = &DialogicTrunk::stepHandler;
			return true;
		}
		if(data.record.append)
			setPosition();

		dt = localtime_r(&ino.st_ctime, &tbuf);
		sprintf(buffer, "%04d%02d%02d,%02d%02d%02d",
			dt->tm_year + 1900, dt->tm_mon + 1, dt->tm_mday,
			dt->tm_hour, dt->tm_min, dt->tm_sec);
		setSymbol(SYM_CREATED, buffer);
		fn = getAnnotation();
		if(fn)
			setSymbol(SYM_ANNOTATION, fn);
		else
			setSymbol(SYM_ANNOTATION, "");
		recordAudio();		 
		return true;
	}
	return false;
}

==> bayonne-0.6.3.tar.gz: bayonne-0.6.3/drivers/dialogic/record.cpp <==
// Copyright (C) 2000 Open Source Telecom Corporation.
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software 
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// As a special exception to the GNU General Public License, permission is
// granted for additional uses of the text contained in its release
// of Bayonne as noted here.
//
// This exception is that permission is hereby granted to link Bayonne 
// with  the Pika MonteCarlo libraries to produce a executable image
// without requiring MonteCarlo itself to be supplied in source form so
// long as each source file so linked contains this exclusion.
//
// This exception does not however invalidate any other reasons why
// the resulting executable file might be covered by the GNU General
// public license or invalidate the licensing requirements of any
// other component or library.
//
// This exception applies only to the code released by OST under the
// name Bayonne.  If you copy code from other releases into a copy of
// Bayonne, as the General Public License permits, the exception does not
// apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own to Bayonne, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice, at which
// point the terms of your modification would be covered under the GPL
// as explicitly stated in "COPYING".

#include "driver.h"

bool DialogicTrunk::recordHandler(TrunkEvent *event)
{
	struct tm *dt, tbuf;
	struct stat ino;
	char buffer[32];
	char *ext, *fn;
	audioinfo_t info;
	unsigned mask;
	
	switch(event->id)
	{
	case TRUNK_STOP_STATE:
		TimerPort::endTimer();
		handler = &DialogicTrunk::stepHandler;
		endRecord();
		return true;
	case TRUNK_DTMF_KEYUP:
		mask = (1 << event->parm.dtmf.digit);
		if(!(mask & data.record.term))
			return false;
	case TRUNK_AUDIO_IDLE:
		TimerPort::endTimer();
		TrunkSignal(TRUNK_SIGNAL_STEP);
		handler = &DialogicTrunk::stepHandler;
		endRecord();
		return true;
	case TRUNK_ENTER_STATE:
		debug->DebugState(this, "record");
		status[id] = 'r';
		if(!Trunk::flags.offhook && interface == NT_ANALOG)
		{
			setHook(true);
			Trunk::flags.offhook = true;
			return true;
		}
	case TRUNK_OFF_HOOK:
		TimerPort::setTimer(data.record.timeout);
		if(data.record.term)
			setDTMFDetect(true);
		else
			Trunk::setDTMFDetect();
		getName(buffer);

		ext = strrchr(data.record.name, '.');
		info.format = AUDIO_FORMAT_RAW;
		info.encoding = MULAW_AUDIO_ENCODING;
		info.order = 0;
		info.annotation = trunk->getSymbol(SYM_ANNOTATION);
		info.rate = 8000;

		if(!ext)
			ext = trunk->getSymbol(SYM_EXTENSION);

		if(!stricmp(ext, ".al"))
			info.encoding = ALAW_AUDIO_ENCODING;
		else if(!stricmp(ext, ".au"))
		{
			info.format = AUDIO_FORMAT_SUN;
			info.order = __BIG_ENDIAN;
		}
		else if(!stricmp(ext, ".wav"))
		{
			info.format = AUDIO_FORMAT_RIFF;
			info.order = __LITTLE_ENDIAN;
		}
		else if(!stricmp(ext, ".vox"))
			info.encoding = DIALOGIC_ADPCM_ENCODING;

		if(data.record.append)
			Open(data.record.name);
		else
			Create(data.record.name, &info);

		fn = getPlayfile();
		if(!isOpen())
		{
			slog(SLOG_ERROR) << data.record.name << ": cannot open" << endl;
			setSymbol(SYM_ERROR, "record-failed");
			TrunkSignal(TRUNK_SIGNAL_ERROR);
			handler = &DialogicTrunk::stepHandler;
			return true;
		}
		if(data.record.append)
			setPosition();

		dt = localtime_r(&ino.st_ctime, &tbuf);
		sprintf(buffer, "%04d%02d%02d,%02d%02d%02d",
			dt->tm_year + 1900, dt->tm_mon + 1, dt->tm_mday,
			dt->tm_hour, dt->tm_min, dt->tm_sec);
		setSymbol(SYM_CREATED, buffer);
		fn = getAnnotation();
		if(fn)
			setSymbol(SYM_ANNOTATION, fn);
		else
			setSymbol(SYM_ANNOTATION, "");
		recordAudio();		 
		return true;
	}
	return false;
}
